@@ -99,7 +99,7 @@ GNUNET_IDENTITY_ego_get_anonymous (void);
  * @param pk set to ego's public key
  */
 void
-GNUNET_IDENTITY_ego_get_public_key (const struct GNUNET_IDENTITY_Ego *ego,
+GNUNET_IDENTITY_ego_get_public_key (struct GNUNET_IDENTITY_Ego *ego,
                                     struct GNUNET_CRYPTO_EcdsaPublicKey *pk);
 
 
@@ -137,10 +137,11 @@ GNUNET_IDENTITY_ego_get_public_key (const struct GNUNET_IDENTITY_Ego *ego,
  *                   NULL if the user just deleted the ego and it
  *                   must thus no longer be used
  */
-typedef void (*GNUNET_IDENTITY_Callback) (void *cls,
-                                          struct GNUNET_IDENTITY_Ego *ego,
-                                          void **ctx,
-                                          const char *name);
+typedef void
+(*GNUNET_IDENTITY_Callback) (void *cls,
+                             struct GNUNET_IDENTITY_Ego *ego,
+                             void **ctx,
+                             const char *name);
 
 
 /**
@@ -180,7 +181,9 @@ GNUNET_IDENTITY_get (struct GNUNET_IDENTITY_Handle *id,
  * @param cls closure
  * @param emsg NULL on success, otherwise an error message
  */
-typedef void (*GNUNET_IDENTITY_Continuation) (void *cls, const char *emsg);
+typedef void
+(*GNUNET_IDENTITY_Continuation) (void *cls,
+                                 const char *emsg);
 
 
 /**
@@ -218,7 +221,8 @@ GNUNET_IDENTITY_disconnect (struct GNUNET_IDENTITY_Handle *h);
  * @param pk private key, NULL on error
  * @param emsg error message, NULL on success
  */
-typedef void (*GNUNET_IDENTITY_CreateContinuation) (
+typedef void
+(*GNUNET_IDENTITY_CreateContinuation) (
   void *cls,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *pk,
   const char *emsg);
@@ -229,6 +233,7 @@ typedef void (*GNUNET_IDENTITY_CreateContinuation) (
  *
  * @param id identity service to use
  * @param name desired name
+ * @param privkey desired private key or NULL to create one
  * @param cont function to call with the result (will only be called once)
  * @param cont_cls closure for @a cont
  * @return handle to abort the operation
@@ -236,6 +241,7 @@ typedef void (*GNUNET_IDENTITY_CreateContinuation) (
 struct GNUNET_IDENTITY_Operation *
 GNUNET_IDENTITY_create (struct GNUNET_IDENTITY_Handle *id,
                         const char *name,
+                        const struct GNUNET_CRYPTO_EcdsaPrivateKey *privkey,
                         GNUNET_IDENTITY_CreateContinuation cont,
                         void *cont_cls);
 
@@ -294,9 +300,9 @@ GNUNET_IDENTITY_cancel (struct GNUNET_IDENTITY_Operation *op);
  * @param cls closure
  * @param ego NULL on error / ego not found
  */
-typedef void (*GNUNET_IDENTITY_EgoCallback) (
-  void *cls,
-  const struct GNUNET_IDENTITY_Ego *ego);
+typedef void
+(*GNUNET_IDENTITY_EgoCallback) (void *cls,
+                                struct GNUNET_IDENTITY_Ego *ego);
 
 /**
  * Handle for ego lookup.
@@ -335,7 +341,8 @@ GNUNET_IDENTITY_ego_lookup_cancel (struct GNUNET_IDENTITY_EgoLookup *el);
  * @param ego NULL on error / ego not found
  * @param ego_name NULL on error, name of the ego otherwise
  */
-typedef void (*GNUNET_IDENTITY_EgoSuffixCallback) (
+typedef void
+(*GNUNET_IDENTITY_EgoSuffixCallback) (
   void *cls,
   const struct GNUNET_CRYPTO_EcdsaPrivateKey *priv,
   const char *ego_name);
@@ -373,8 +380,9 @@ GNUNET_IDENTITY_ego_lookup_by_suffix (const struct
  * @param el handle for lookup to abort
  */
 void
-GNUNET_IDENTITY_ego_lookup_by_suffix_cancel (struct
-                                             GNUNET_IDENTITY_EgoSuffixLookup *el);
+GNUNET_IDENTITY_ego_lookup_by_suffix_cancel (
+  struct GNUNET_IDENTITY_EgoSuffixLookup *el);
+
 
 #if 0 /* keep Emacsens' auto-indent happy */
 {
